@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2004 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.cc,v 1.126 2005/10/18 12:34:21 lav Exp $ */
+/* $Id: FileAccess.cc,v 1.129 2006/04/19 09:48:02 lav Exp $ */
 
 #include <config.h>
 
@@ -40,6 +40,7 @@
 #include "netrc.h"
 #include "ArgV.h"
 #include "ConnectionSlot.h"
+#include "SignalHook.h"
 #ifdef WITH_MODULES
 # include "module.h"
 #endif
@@ -48,6 +49,8 @@ FileAccess *FileAccess::chain=0;
 
 void FileAccess::Init()
 {
+   ClassInit();
+
    vproto=0;
    portname=0;
    hostname=0;
@@ -674,7 +677,7 @@ void FileAccess::Chdir(const char *path,bool verify)
 {
    cwd.ExpandTilde(home);
 
-   delete new_cwd;
+   Close();
    new_cwd=new Path(&cwd);
    new_cwd->Change(path,false);
 
@@ -690,7 +693,7 @@ void FileAccess::Chdir(const char *path,bool verify)
 
 void FileAccess::PathVerify(const Path &p)
 {
-   delete new_cwd;
+   Close();
    new_cwd=new Path(p);
    Open(new_cwd->path,CHANGE_DIR);
 }
@@ -949,8 +952,10 @@ FileAccess *FileAccess::NextSameSite(FA *scan)
    return 0;
 }
 
-FileAccess *FileAccess::New(const char *proto,const char *host)
+FileAccess *FileAccess::New(const char *proto,const char *host,const char *port)
 {
+   ClassInit();
+
    if(!strcmp(proto,"slot"))
    {
       FA *session=ConnectionSlot::FindSession(host);
@@ -973,6 +978,9 @@ FileAccess *FileAccess::New(const char *proto,const char *host)
       }
    }
 
+   if(host)
+      session->Connect(host,port);
+
    return session;
 }
 FileAccess *FileAccess::New(const ParsedURL *u,bool dummy)
@@ -1261,8 +1269,16 @@ void FileAccess::Path::ExpandTilde(const Path &home)
 #else
 # define _sftp
 #endif
+bool FileAccess::class_inited;
 void FileAccess::ClassInit()
 {
+   if(class_inited)
+      return;
+   class_inited=true;
+
+   SignalHook::ClassInit();
+   ResMgr::ClassInit();
+
    _ftp;
    _file;
    _http;
