@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1999-2000 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1999-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileCopy.cc,v 1.118 2005/12/27 12:16:58 lav Exp $ */
+/* $Id: FileCopy.cc,v 1.121 2006/03/13 10:42:50 lav Exp $ */
 
 /* FileCopyPeer behaviour:
     1) when suspended, does nothing
@@ -149,8 +149,11 @@ int FileCopy::Do()
       }
       if(get->Error() && get->Size()==0)
       {
-	 put->PutEOF();
-	 Roll(put);
+	 if(put->GetPos()>0)
+	 {
+	    put->PutEOF();
+	    Roll(put);
+	 }
       get_error:
 	 SetError(get->ErrorText());
 	 return MOVED;
@@ -402,8 +405,8 @@ void FileCopy::Init()
    max_buf=0x10000;
    cont=false;
    error_text=0;
-   rate        =new Speedometer("xfer:rate-period");
-   rate_for_eta=new Speedometer("xfer:eta-period");
+   rate        =MakeRef(new Speedometer("xfer:rate-period"));
+   rate_for_eta=MakeRef(new Speedometer("xfer:eta-period"));
    put_buf=0;
    put_eof_pos=0;
    bytes_count=0;
@@ -418,18 +421,18 @@ void FileCopy::Init()
 FileCopy::FileCopy(FileCopyPeer *s,FileCopyPeer *d,bool c)
 {
    Init();
-   get=s;
-   put=d;
+   get=MakeRef(s);
+   put=MakeRef(d);
    cont=c;
 }
 FileCopy::~FileCopy()
 {
-   Delete(get);
-   Delete(put);
+   DeleteRef(get);
+   DeleteRef(put);
    delete line_buffer;
    xfree(error_text);
-   Delete(rate);
-   Delete(rate_for_eta);
+   DeleteRef(rate);
+   DeleteRef(rate_for_eta);
 }
 FileCopy *FileCopy::New(FileCopyPeer *s,FileCopyPeer *d,bool c)
 {
@@ -469,8 +472,8 @@ void FileCopy::SetError(const char *str)
 {
    xfree(error_text);
    error_text=xstrdup(str);
-   Delete(get); get=0;
-   Delete(put); put=0;
+   DeleteRef(get);
+   DeleteRef(put);
 }
 
 void FileCopy::LineBuffered(int s)
@@ -793,7 +796,7 @@ int FileCopyPeerFA::Do()
 	       // FIXME: set date for real.
 	       date_set=true;
 	       if(!verify)
-		  verify=new FileVerificator(session,file);
+		  verify=MakeRef(new FileVerificator(session,file));
 	       return MOVED;
 	    }
 	    else if(res==FA::IN_PROGRESS)
@@ -1192,7 +1195,7 @@ FileCopyPeerFA::~FileCopyPeerFA()
    }
    xfree(file);
    xfree(orig_url);
-   Delete(verify);
+   DeleteRef(verify);
 }
 
 FileCopyPeerFA::FileCopyPeerFA(ParsedURL *u,int m)
@@ -1262,7 +1265,7 @@ FileCopyPeerFDStream::~FileCopyPeerFDStream()
    if(delete_stream)
       delete stream;
    delete put_ll_timer;
-   Delete(verify);
+   DeleteRef(verify);
 }
 
 void FileCopyPeerFDStream::Seek_LL()
@@ -1379,7 +1382,7 @@ int FileCopyPeerFDStream::Do()
 	    if(stream && delete_stream && !stream->Done())
 	       return m;
 	    if(!verify)
-	       verify=new FileVerificator(stream);
+	       verify=MakeRef(new FileVerificator(stream));
 	    return MOVED;
 	 }
 	 if(seek_pos==0)
@@ -1698,7 +1701,7 @@ FileCopyPeerDirList::FileCopyPeerDirList(FA *s,ArgV *v)
    : FileCopyPeer(GET)
 {
    session=s;
-   dl=session->MakeDirList(v);
+   dl=MakeRef(session->MakeDirList(v));
    if(dl==0)
       eof=true;
    can_seek=false;
@@ -1707,7 +1710,7 @@ FileCopyPeerDirList::FileCopyPeerDirList(FA *s,ArgV *v)
 
 FileCopyPeerDirList::~FileCopyPeerDirList()
 {
-   Delete(dl);
+   DeleteRef(dl);
    SessionPool::Reuse(session);
 }
 
