@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Job.h,v 1.22 2005/10/05 11:12:17 lav Exp $ */
+/* $Id: Job.h,v 1.25 2006/04/19 09:48:03 lav Exp $ */
 
 #ifndef JOB_H
 #define JOB_H
@@ -107,9 +107,10 @@ public:
       return j && !j->Done();
    }
    void Kill(int n);
-   void Kill(Job*);
+   static void Kill(Job*);
    void SendSig(int n,int sig);
-   void KillAll();
+   static void KillAll();
+   static void Cleanup();
 
    void vfprintf(FILE *file,const char *fmt,va_list v);
    // CmdExec redefines this, and traps all messages of its children.
@@ -130,6 +131,8 @@ public:
 
    virtual off_t GetBytesCount() { return 0; }
    virtual double GetTimeSpent() { return 0; }
+
+   void WaitDone();
 };
 
 class SessionJob : public Job
