@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1999-2000 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1999-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: NetAccess.cc,v 1.78 2005/04/07 15:30:22 lav Exp $ */
+/* $Id: NetAccess.cc,v 1.80 2006/02/06 10:57:26 lav Exp $ */
 
 #include <config.h>
 
@@ -118,7 +118,7 @@ void NetAccess::Reconfig(const char *name)
 
    const char *c=hostname;
 
-   timeout = ResMgr::Query("net:timeout",c);
+   timeout = TimeInterval(ResMgr::Query("net:timeout",c)).Seconds();
    reconnect_interval = ResMgr::Query("net:reconnect-interval-base",c);
    reconnect_interval_multiplier = ResMgr::Query("net:reconnect-interval-multiplier",c);
    if(reconnect_interval_multiplier<1)
