@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: SMTask.cc,v 1.41 2006/02/16 08:03:32 lav Exp $ */
+/* $Id: SMTask.cc,v 1.42 2006/05/13 05:46:10 lav Exp $ */
 
 #include <config.h>
 #include <assert.h>
@@ -131,21 +131,6 @@ void SMTask::Delete(SMTask *task)
    if(!task->running && !task->ref_count)
       delete task;
 }
-void SMTask::_DeleteRef(SMTask *task)
-{
-   if(!task)
-      return;
-   assert(task->ref_count>0);
-   task->ref_count--;
-   Delete(task);
-   task=0;
-}
-void SMTask::_MakeRef(SMTask *task)
-{
-   if(!task)
-      return;
-   task->ref_count++;
-}
 
 void SMTask::Enter(SMTask *task)
 {
