@@ -39,9 +39,6 @@ class SMTask
    bool	 suspended;
    bool	 suspended_slave;
 
-   static void _MakeRef(SMTask*);
-   static void _DeleteRef(SMTask*);
-
 protected:
    int	 running;
    int	 ref_count;
@@ -93,8 +90,15 @@ public:
 
    void DeleteLater() { deleting=true; }
    static void Delete(SMTask *);
-   template<class T> static void DeleteRef(T *&task) { _DeleteRef(task); task=0; }
-   template<class T> static T *MakeRef(T *task) { _MakeRef(task); return task; }
+   static SMTask *_MakeRef(SMTask *task) { if(task) task->ref_count++; return task; }
+   static void _DeleteRef(SMTask *task)  { if(task) task->ref_count--; Delete(task); }
+#if __GNUC__
+   template<typename T> static void DeleteRef(T *&task) { _DeleteRef(task); task=0; }
+   template<typename T> static T *MakeRef(T *task) { _MakeRef(task); return task; }
+#else
+# define DeleteRef(task) do { _DeleteRef((task)); (task)=0; } while(0)
+# define MakeRef(task)   (_MakeRef((task)),(task))
+#endif
    static int Roll(SMTask *);
    static void RollAll(int max_time);
 
