@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: commands.cc,v 1.246 2006/04/24 10:32:00 lav Exp $ */
+/* $Id: commands.cc,v 1.249 2006/05/13 05:45:07 lav Exp $ */
 
 #include <config.h>
 
@@ -36,6 +36,7 @@
 #ifdef HAVE_DLFCN_H
 # include <dlfcn.h>
 #endif
+#include <mbswidth.h>
 
 #include "CmdExec.h"
 #include "GetJob.h"
@@ -2554,7 +2555,7 @@ CMD(help)
 CMD(ver)
 {
    printf(
-      _("LFTP | Version %s | Copyright (c) 1996-2006 Alexander V. Lukyanov\n"),VERSION);
+      _("LFTP | Version %s | Copyright (c) 1996-%d Alexander V. Lukyanov\n"),VERSION,2006);
    printf("\n");
    printf(
       _("LFTP is free software, covered by the GNU General Public License, and you are\n"
@@ -2565,8 +2566,14 @@ CMD(ver)
       _("Send bug reports and questions to <%s>.\n"),"lftp@uniyar.ac.ru");
 
 #if defined(HAVE_DLOPEN) && defined(RTLD_DEFAULT)
+   /* Show some of loaded libraries. Modules can load those libraries on
+      demand so use dlsym to avoid linking with them just for showing version. */
    printf("\n");
-   printf(_("Libraries used: "));
+   const char *msg=_("Libraries used: ");
+   int mbflags=MBSW_ACCEPT_INVALID|MBSW_ACCEPT_UNPRINTABLE;
+   int col=mbswidth(msg,mbflags);
+   int width=parent->status_line?parent->status_line->GetWidth():80;
+   printf("%s",msg);
 
    struct VersionInfo
    {
@@ -2610,6 +2617,7 @@ CMD(ver)
       {"OpenSSL",    "SSL_version_str",	     VersionInfo::STRING_PTR,"OpenSSL "},
       {"GnuTLS",     "gnutls_check_version", VersionInfo::FUNC0,     0},
       {"libiconv",   "_libiconv_version",    VersionInfo::INT8_8,    0},
+      {"zlib",	     "zlibVersion",	     VersionInfo::FUNC0,     0},
       {0}
    };
 
@@ -2619,7 +2627,19 @@ CMD(ver)
       const char *v=scan->query();
       if(!v)
 	 continue;
-      printf("%s%s %s",need_comma?", ":"",scan->lib_name,v);
+      char buf[256];
+      sprintf(buf,", %s %s",scan->lib_name,v);
+      int skip=need_comma?0:2;
+      int w=mbswidth(buf+skip,mbflags);
+      if(col+w>=width)
+      {
+	 buf[1]='\n';
+	 col=w-2+skip;
+	 skip/=2;
+      }
+      else
+	 col+=w;
+      printf("%s",buf+skip);
       need_comma=true;
    }
    printf("\n");
@@ -3193,9 +3213,11 @@ CMD(get1)
    if(args->getnext()!=0)
       goto usage;
 
+   bool auto_rename=false;
    if(dst==0 || dst[0]==0)
    {
       dst=basename_ptr(src);
+      auto_rename=true;
    }
    else
    {
@@ -3208,6 +3230,7 @@ CMD(get1)
 	    strcpy(dst1,dst);
 	    strcat(dst1,bn);
 	    dst=dst1;
+	    auto_rename=true;
 	 }
       }
    }
@@ -3248,6 +3271,7 @@ CMD(get1)
       dst_peer=FileCopyPeerFDStream::NewPut(dst,cont||target_region_begin>0);
    else
       dst_peer=new FileCopyPeerFA(&dst_url,FA::STORE);
+   dst_peer->AutoRename(auto_rename);
    if(!cont && (target_region_begin>0 || target_region_end!=FILE_END))
       dst_peer->SetRange(target_region_begin,target_region_end);
 
