@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2004 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ftpclass.h,v 1.126 2005/05/18 05:57:09 lav Exp $ */
+/* $Id: ftpclass.h,v 1.130 2006/02/06 11:00:41 lav Exp $ */
 
 #ifndef FTPCLASS_H
 #define FTPCLASS_H
@@ -131,6 +131,7 @@ class Ftp : public NetAccess
       void InitTelnetLayer();
       void SetControlConnectionTranslation(const char *cs);
 
+      void CloseDataSocket(); // only closes socket, does not delete iobuf.
       void CloseDataConnection();
       void AbortDataConnection();
       void CloseAbortedDataConnection();
@@ -181,7 +182,7 @@ class Ftp : public NetAccess
 	 SITE_UTIME,
 	 QUOTED		// check response for any command submitted by QUOTE_CMD
 #if USE_SSL
-	 ,AUTH_TLS,PROT,SSCN
+	 ,AUTH_TLS,PROT,SSCN,CCC
 #endif
       };
 
@@ -304,6 +305,7 @@ private:
    void SendAuth(const char *auth);
    void TuneConnectionAfterFEAT();
    void SendOPTS_MLST();
+   void SendPROT(char want_prot);
 
    const char *QueryStringWithUserAtHost(const char *);
 
